git@vger.kernel.org mailing list mirror (one of many)
 help / color / mirror / code / Atom feed
From: Alban Gruin <alban.gruin@gmail.com>
To: Phillip Wood <phillip.wood@dunelm.org.uk>,
	Johannes Schindelin <Johannes.Schindelin@gmx.de>,
	Junio C Hamano <gitster@pobox.com>,
	Elijah Newren <newren@gmail.com>,
	Rohit Ashiwal <rohit.ashiwal265@gmail.com>,
	Git Mailing List <git@vger.kernel.org>
Subject: Re: [PATCH v2 4/5] rebase -i: support --ignore-date
Date: Sun, 10 May 2020 13:14:39 +0200	[thread overview]
Message-ID: <7d72953e-83d2-b60e-1a61-f40fde841957@gmail.com> (raw)
In-Reply-To: <20200429102521.47995-5-phillip.wood123@gmail.com>

Hi Phillip,

Le 29/04/2020 à 12:25, Phillip Wood a écrit :
> From: Phillip Wood <phillip.wood@dunelm.org.uk>
> 
> As part of the on-going effort to retire the apply rebase backend
> teach the merge backend how to handle --ignore-date. We take care to
> handle the combination of --ignore-date and
> --committer-date-is-author-date in the same way as the apply backend.
> 
> Original-patch-by: Rohit Ashiwal <rohit.ashiwal265@gmail.com>
> Signed-off-by: Phillip Wood <phillip.wood@dunelm.org.uk>
> ---
>  Documentation/git-rebase.txt   |  7 +++--
>  builtin/rebase.c               | 13 +++++---
>  sequencer.c                    | 49 +++++++++++++++++++++++++++--
>  sequencer.h                    |  1 +
>  t/t3436-rebase-more-options.sh | 57 ++++++++++++++++++++++++++++++++++
>  5 files changed, 117 insertions(+), 10 deletions(-)
> 
> -%<-
>
> diff --git a/sequencer.c b/sequencer.c
> index 8dff8b9b95..339dbf4a59 100644
> --- a/sequencer.c
> +++ b/sequencer.c
> @@ -150,6 +150,7 @@ static GIT_PATH_FUNC(rebase_path_refs_to_delete, "rebase-merge/refs-to-delete")
>   */
>  static GIT_PATH_FUNC(rebase_path_gpg_sign_opt, "rebase-merge/gpg_sign_opt")
>  static GIT_PATH_FUNC(rebase_path_cdate_is_adate, "rebase-merge/cdate_is_adate")
> +static GIT_PATH_FUNC(rebase_path_ignore_date, "rebase-merge/ignore_date")
>  static GIT_PATH_FUNC(rebase_path_orig_head, "rebase-merge/orig-head")
>  static GIT_PATH_FUNC(rebase_path_verbose, "rebase-merge/verbose")
>  static GIT_PATH_FUNC(rebase_path_quiet, "rebase-merge/quiet")
> @@ -889,6 +890,24 @@ static const char *author_date_from_env_array(const struct argv_array *env)
>  	BUG("GIT_AUTHOR_DATE missing from author script");
>  }
>  
> +/* Construct a free()able author string with current time as the author date */
> +static char *ignore_author_date(const char *author)
> +{
> +	int len = strlen(author);
> +	struct ident_split ident;
> +	struct strbuf new_author = STRBUF_INIT;
> +
> +	if (split_ident_line(&ident, author, len) < 0) {
> +		error(_("malformed ident line '%s'"), author);
> +		return NULL;
> +	}

Nit: add an empty line here?

> +	len = ident.mail_end - ident.name_begin + 1;
> +
> +	strbuf_addf(&new_author, "%.*s ", len, ident.name_begin);
> +	datestamp(&new_author);
> +	return strbuf_detach(&new_author, NULL);
> +}
> +
>  static const char staged_changes_advice[] =
>  N_("you have staged changes in your working tree\n"
>  "If these changes are meant to be squashed into the previous commit, run:\n"
> @@ -957,7 +976,11 @@ static int run_git_commit(struct repository *r,
>  
>  	if (opts->committer_date_is_author_date)
>  		argv_array_pushf(&cmd.env_array, "GIT_COMMITTER_DATE=%s",
> +				 opts->ignore_date ?
> +				 "" :
>  				 author_date_from_env_array(&cmd.env_array));
> +	if (opts->ignore_date)
> +		argv_array_push(&cmd.env_array, "GIT_AUTHOR_DATE=");
>  

Perhaps this could be done in read_env_script(), too, instead of fixing
up what this function did right after calling it, twice?  Something like
this:

---- snip ----
index 339dbf4a59..3a7a80bab7 100644
--- a/sequencer.c
+++ b/sequencer.c
@@ -840,11 +840,12 @@ int read_author_script(const char *path, char
**name, char **email, char **date,
 }

 /*
  * Read a GIT_AUTHOR_NAME, GIT_AUTHOR_EMAIL AND GIT_AUTHOR_DATE from a
  * file with shell quoting into struct argv_array. Returns -1 on
  * error, 0 otherwise.
  */
-static int read_env_script(struct argv_array *env)
+static int read_env_script(struct replay_opts *opts,
+                          struct argv_array *env)
 {
        char *name, *email, *date;

@@ -854,7 +855,17 @@ static int read_env_script(struct argv_array *env)

        argv_array_pushf(env, "GIT_AUTHOR_NAME=%s", name);
        argv_array_pushf(env, "GIT_AUTHOR_EMAIL=%s", email);
-       argv_array_pushf(env, "GIT_AUTHOR_DATE=%s", date);
+
+       if (opts->ignore_date) {
+               argv_array_push(env, "GIT_AUTHOR_DATE=");
+               argv_array_push(env, "GIT_COMMITTER_DATE=");
+       } else {
+               argv_array_pushf(env, "GIT_AUTHOR_DATE=%s", date);
+
+               if (opts->committer_date_is_author_date)
+                       argv_array_pushf(env, "GIT_COMMITTER_DATE=%s",
date);
+       }
+
        free(name);
        free(email);
        free(date);
---- snap ----
@@ -840,11 +840,12 @@ int read_author_script(const char *path, char

 /*
- * Read a GIT_AUTHOR_NAME, GIT_AUTHOR_EMAIL AND GIT_AUTHOR_DATE from a
- * file with shell quoting into struct argv_array. Returns -1 on
- * error, 0 otherwise.
+ * Read a GIT_AUTHOR_NAME, GIT_AUTHOR_EMAIL and GIT_AUTHOR_DATE from a
+ * file with shell quoting into struct argv_array, and set
+ * GIT_COMMITTER_DATE if needed. Returns -1 on error, 0 otherwise.
  */

>  	argv_array_push(&cmd.args, "commit");
>  
> @@ -1386,7 +1409,8 @@ static int try_to_commit(struct repository *r,
>  		strbuf_addf(&date, "@%.*s %.*s",
>  			    (int)(ident.date_end - ident.date_begin), ident.date_begin,
>  			    (int)(ident.tz_end - ident.tz_begin), ident.tz_begin);
> -		res = setenv("GIT_COMMITTER_DATE", date.buf, 1);
> +		res = setenv("GIT_COMMITTER_DATE",
> +			     opts->ignore_date ? "" : date.buf, 1);
>  		strbuf_release(&date);
>  
>  		if (res)
> @@ -1452,6 +1476,15 @@ static int try_to_commit(struct repository *r,
>  
>  	reset_ident_date();
>  
> +	if (opts->ignore_date) {
> +		author = ignore_author_date(author);
> +		if (!author) {
> +			res = -1;
> +			goto out;
> +		}
> +		free(author_to_free);
> +		author_to_free = (char *)author;
> +	}

Nit: add an empty line here?

Cheers,
Alban


  reply	other threads:[~2020-05-10 11:14 UTC|newest]

Thread overview: 130+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2020-04-07 14:11 [PATCH 0/6] fixup ra/rebase-i-more-options Phillip Wood
2020-04-07 14:11 ` [PATCH 1/6] Revert "Revert "Merge branch 'ra/rebase-i-more-options'"" Phillip Wood
2020-04-07 15:16   ` Elijah Newren
2020-04-07 18:01     ` Phillip Wood
2020-04-07 21:04     ` Junio C Hamano
2020-04-07 21:31       ` Junio C Hamano
2020-04-12 17:47         ` Johannes Schindelin
2020-04-13  9:58           ` Phillip Wood
2020-04-13 22:05             ` Junio C Hamano
2020-04-07 14:11 ` [PATCH 2/6] t3433: remove loops from tests Phillip Wood
2020-04-07 14:30   ` Elijah Newren
2020-04-07 14:11 ` [PATCH 3/6] t3433: only compare commit dates Phillip Wood
2020-04-07 14:11 ` [PATCH 4/6] rebase -i: fix --committer-date-is-author-date Phillip Wood
2020-04-07 15:05   ` Elijah Newren
2020-04-07 18:11     ` Phillip Wood
2020-04-07 14:11 ` [PATCH 5/6] Revert "sequencer: allow callers of read_author_script() to ignore fields" Phillip Wood
2020-04-07 15:06   ` Elijah Newren
2020-04-07 14:11 ` [PATCH 6/6] t3433: improve coverage Phillip Wood
2020-04-07 15:13   ` Elijah Newren
2020-04-07 18:16     ` Phillip Wood
2020-04-07 15:17 ` [PATCH 0/6] fixup ra/rebase-i-more-options Elijah Newren
2020-04-07 18:18   ` Phillip Wood
2020-04-07 23:04 ` Junio C Hamano
2020-04-29 10:25 ` [PATCH v2 0/5] cleanup ra/rebase-i-more-options Phillip Wood
2020-04-29 10:25   ` [PATCH v2 1/5] rebase -i: add --ignore-whitespace flag Phillip Wood
2020-05-13  3:54     ` Elijah Newren
2020-05-14  9:47       ` Phillip Wood
2020-04-29 10:25   ` [PATCH v2 2/5] rebase -i: support --committer-date-is-author-date Phillip Wood
2020-05-10 11:14     ` Alban Gruin
2020-05-13  4:08     ` Elijah Newren
2020-04-29 10:25   ` [PATCH v2 3/5] sequencer: rename amend_author to author_to_free Phillip Wood
2020-04-29 10:25   ` [PATCH v2 4/5] rebase -i: support --ignore-date Phillip Wood
2020-05-10 11:14     ` Alban Gruin [this message]
2020-05-12 14:47       ` Phillip Wood
2020-05-13 15:33         ` Junio C Hamano
2020-05-13  3:54     ` Elijah Newren
2020-04-29 10:25   ` [PATCH v2 5/5] rebase: add --reset-author-date Phillip Wood
2020-04-29 19:59   ` [PATCH v2 0/5] cleanup ra/rebase-i-more-options Junio C Hamano
2020-05-13  3:57     ` Elijah Newren
2020-05-21 10:14 ` [PATCH v3 " Phillip Wood
2020-05-21 10:14   ` [PATCH v3 1/5] rebase -i: add --ignore-whitespace flag Phillip Wood
2020-05-21 10:14   ` [PATCH v3 2/5] rebase -i: support --committer-date-is-author-date Phillip Wood
2020-05-21 10:14   ` [PATCH v3 3/5] sequencer: rename amend_author to author_to_free Phillip Wood
2020-05-21 10:14   ` [PATCH v3 4/5] rebase -i: support --ignore-date Phillip Wood
2020-05-23 12:30     ` Đoàn Trần Công Danh
2020-05-23 15:43       ` Phillip Wood
2020-05-23 15:52         ` Đoàn Trần Công Danh
2020-05-23 18:50           ` Phillip Wood
2020-05-23 23:05             ` Đoàn Trần Công Danh
2020-05-27  9:55               ` Phillip Wood
2020-05-24 16:32           ` Junio C Hamano
2020-05-21 10:14   ` [PATCH v3 5/5] rebase: add --reset-author-date Phillip Wood
2020-05-22 15:54   ` [PATCH v3 0/5] cleanup ra/rebase-i-more-options Elijah Newren
2020-05-23  8:55     ` Phillip Wood
2020-05-23  6:59   ` Johannes Schindelin
2020-05-27 17:33 ` [PATCH v4 " Phillip Wood
2020-05-27 17:33   ` [PATCH v4 1/5] rebase -i: add --ignore-whitespace flag Phillip Wood
2020-05-29  2:38     ` Johannes Schindelin
2020-06-01  9:23       ` Kerry, Richard
2020-06-01 10:26       ` Phillip Wood
2020-06-01 21:03         ` Johannes Schindelin
2020-05-27 17:33   ` [PATCH v4 2/5] rebase -i: support --committer-date-is-author-date Phillip Wood
2020-05-29  2:52     ` Johannes Schindelin
2020-06-01 10:33       ` Phillip Wood
2020-05-27 17:33   ` [PATCH v4 3/5] sequencer: rename amend_author to author_to_free Phillip Wood
2020-05-27 17:33   ` [PATCH v4 4/5] rebase -i: support --ignore-date Phillip Wood
2020-05-27 17:33   ` [PATCH v4 5/5] rebase: add --reset-author-date Phillip Wood
2020-05-27 17:57     ` [PATCH v4 6/5] fixup! " Phillip Wood
2020-05-28 13:17       ` Đoàn Trần Công Danh
2020-05-29  2:59         ` Johannes Schindelin
2020-06-01 10:36           ` Phillip Wood
2020-05-27 21:10   ` [PATCH v4 0/5] cleanup ra/rebase-i-more-options Junio C Hamano
2020-06-26  9:55 ` [PATCH v5 " Phillip Wood
2020-06-26  9:55   ` [PATCH v5 1/5] rebase -i: add --ignore-whitespace flag Phillip Wood
2020-06-26 13:37     ` Đoàn Trần Công Danh
2020-06-26 14:43       ` Phillip Wood
2020-06-26 16:03         ` Junio C Hamano
2020-06-29 14:14         ` Đoàn Trần Công Danh
2020-07-13 10:02           ` Phillip Wood
2020-06-26 15:43     ` Junio C Hamano
2020-06-26  9:55   ` [PATCH v5 2/5] rebase -i: support --committer-date-is-author-date Phillip Wood
2020-06-26  9:55   ` [PATCH v5 3/5] sequencer: rename amend_author to author_to_free Phillip Wood
2020-06-26  9:55   ` [PATCH v5 4/5] rebase -i: support --ignore-date Phillip Wood
2020-06-26 14:09     ` Đoàn Trần Công Danh
2020-06-26 14:38       ` Phillip Wood
2020-06-26 16:29     ` Junio C Hamano
2020-06-26  9:55   ` [PATCH v5 5/5] rebase: add --reset-author-date Phillip Wood
2020-06-26 16:35     ` Junio C Hamano
2020-06-26 18:07       ` Phillip Wood
2020-06-26 15:04   ` [PATCH v5 0/5] cleanup ra/rebase-i-more-options Junio C Hamano
2020-07-13 10:10 ` [PATCH v6 0/5] fixup ra/rebase-i-more-options Phillip Wood
2020-07-13 10:10   ` [PATCH v6 1/5] rebase -i: add --ignore-whitespace flag Phillip Wood
2020-07-13 10:10   ` [PATCH v6 2/5] rebase -i: support --committer-date-is-author-date Phillip Wood
2020-07-15 14:27     ` Đoàn Trần Công Danh
2020-07-16  8:23       ` Phillip Wood
2020-07-16 13:06         ` Đoàn Trần Công Danh
2020-07-16 15:17           ` Phillip Wood
2020-07-16 17:34             ` Phillip Wood
2020-07-17  0:25               ` Đoàn Trần Công Danh
2020-07-13 10:10   ` [PATCH v6 3/5] sequencer: rename amend_author to author_to_free Phillip Wood
2020-07-13 10:10   ` [PATCH v6 4/5] rebase -i: support --ignore-date Phillip Wood
2020-07-13 10:10   ` [PATCH v6 5/5] rebase: add --reset-author-date Phillip Wood
2020-07-13 15:28   ` [PATCH v6 0/5] fixup ra/rebase-i-more-options Junio C Hamano
2020-07-15  8:55     ` Phillip Wood
2020-07-16 17:32 ` [PATCH v7 0/5] cleanup ra/rebase-i-more-options Phillip Wood
2020-07-16 17:32   ` [PATCH v7 1/5] rebase -i: add --ignore-whitespace flag Phillip Wood
2020-07-16 17:32   ` [PATCH v7 2/5] rebase -i: support --committer-date-is-author-date Phillip Wood
2020-08-13 13:46     ` Johannes Schindelin
2020-07-16 17:32   ` [PATCH v7 3/5] sequencer: rename amend_author to author_to_free Phillip Wood
2020-07-16 17:32   ` [PATCH v7 4/5] rebase -i: support --ignore-date Phillip Wood
2020-08-13 14:07     ` Johannes Schindelin
2020-07-16 17:32   ` [PATCH v7 5/5] rebase: add --reset-author-date Phillip Wood
2020-07-16 17:39   ` [PATCH v7 0/5] cleanup ra/rebase-i-more-options Junio C Hamano
2020-08-13 14:24   ` Johannes Schindelin
2020-08-13 17:46     ` Junio C Hamano
2020-08-13 19:51       ` Phillip Wood
2020-08-17 17:39 ` [PATCH v8 " Phillip Wood
2020-08-17 17:40   ` [PATCH v8 1/5] rebase -i: add --ignore-whitespace flag Phillip Wood
2020-08-17 17:40   ` [PATCH v8 2/5] am: stop exporting GIT_COMMITTER_DATE Phillip Wood
2020-08-17 19:12     ` Junio C Hamano
2020-08-19 10:20       ` Phillip Wood
2020-08-19 15:51         ` Junio C Hamano
2020-08-20 15:23           ` Phillip Wood
2020-08-17 17:40   ` [PATCH v8 3/5] rebase -i: support --committer-date-is-author-date Phillip Wood
2020-08-26 21:41     ` Junio C Hamano
2020-08-17 17:40   ` [PATCH v8 4/5] rebase -i: support --ignore-date Phillip Wood
2020-08-19 10:22     ` Phillip Wood
2020-08-19 22:20       ` Junio C Hamano
2020-08-20 15:16         ` Phillip Wood
2020-08-17 17:40   ` [PATCH v8 5/5] rebase: add --reset-author-date Phillip Wood

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

  List information: http://vger.kernel.org/majordomo-info.html

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=7d72953e-83d2-b60e-1a61-f40fde841957@gmail.com \
    --to=alban.gruin@gmail.com \
    --cc=Johannes.Schindelin@gmx.de \
    --cc=git@vger.kernel.org \
    --cc=gitster@pobox.com \
    --cc=newren@gmail.com \
    --cc=phillip.wood@dunelm.org.uk \
    --cc=rohit.ashiwal265@gmail.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
Code repositories for project(s) associated with this public inbox

	https://80x24.org/mirrors/git.git

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).